/**
  *  \file client/tiles/baseheader.cc
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <algorithm>
#include "client/tiles/baseheader.h"
#include "cpluslib/format.h"
#include "game/config.h"
#include "game/planet.h"
#include "resmgr/resid.h"
#include "util/nls.h"


WBaseScreenHeaderTile::WBaseScreenHeaderTile(GObjectType& type, bool forTask)
    : WControlScreenHeaderTile(type, forTask ? bCScr : bAuto + bAdd, IntExecutionContext::pkBaseTask)
{ }

string_t
WBaseScreenHeaderTile::getTitle()
{
    return getObject()->getName();
}

string_t
WBaseScreenHeaderTile::getSubtitle()
{
    string_t result;
    if (GPlanet* p = dynamic_cast<GPlanet*>(getObject())) {
        int16 level = p->unit_scores.getScore(planet_score_definitions.lookupScore(ScoreId_ExpLevel));
        const char* fmt = (level >= 0
                           ? _("(Id #%d, %s)")
                           : _("(Id #%d)"));
        result = format(fmt, getObject()->getId(), getExperienceLevelName(level));
    }
    return result;
}

ResId
WBaseScreenHeaderTile::getPictureId()
{
    int max_tech = 0;
    int id = 0;
    if (GPlanet* p = dynamic_cast<GPlanet*>(getObject())) {
        id = p->getId();
        if (p->isPlayed() && p->hasBase()) {
            max_tech = std::max(std::max(p->getBaseTech(tl_Engine),
                                         p->getBaseTech(tl_Hull)),
                                std::max(p->getBaseTech(tl_Beam),
                                         p->getBaseTech(tl_Torpedo)));
        }
    }
    return ResId(res::base, max_tech, id);
}

