 /**
  *  \file vcrplay.h
  *  \brief VCR Player (GUI)
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_VCRPLAY_H
#define PCC_V2_VCRPLAY_H

#include "cpluslib/smartptr.h"
#include "cpluslib/call.h"
#include "ui/ui.h"
#include "game/vcr.h"
#include "game/vcrdb.h"
#include "ui/commands.h"
#include "ui/widgets/keytranslator.h"
#include "ui/window.h"
#include "ui/widgets/button.h"

class GClassicVcrDatabase;
class GClassicVcrEntry;

enum {
    cm_VCR_Prev = cm_VcrSelectionFirst,
    cm_VCR_Next,
    cm_VCR_LeftInfo,
    cm_VCR_RightInfo,
    cm_VCR_Diagram
};

/** VCR Selector Widget.
    \cmd cm_VCR_Prev: switch to previous VCR
    \cmd cm_VCR_Next: switch to next VCR */
class WVcrSelector : public UIWidget {
    int index;                  /**< Currently displayed battle. Range is [0, db->getVcrCount()) */
    GClassicVcrDatabase& db;    /**< VCR Database to play. */
    GClassicVcrEntry* entry;    /**< Current database entry. Equals db->getEntry(index). */
    Ptr<VcrPlayer> player;      /**< VCR Player to use. Non-null while computing, otherwise 0. */
    int disp_status;            /**< Displayed status. 0 if battle ending not known, nonzero else. */
    bool playing;

    UIButton btn_l;
    UIButton btn_r;
    UIButton btn_tab;

    void drawWarrior(GfxContext& ctx, int x, int y, int w, int side);
    void drawStatus(GfxContext& ctx);
    void maybeRestartPlayer();
 public:
    WVcrSelector(GClassicVcrDatabase& adb);
    ~WVcrSelector();

    void selectVcr(int aindex);
    void drawContent(GfxCanvas& can);
    void getLayoutInfo(LayoutInfo&);
    int getCurrentVcr() const
        { return index; }
    GClassicVcrDatabase& getCurrentDatabase()
        { return db; }

    bool handleEvent(const UIEvent& e, bool second_pass);
    void onResize(GfxRect oldsize, bool by_layout);

    /* slots */
    void playIt(int dummy=0);
    void next(int dummy=0);
    void prev(int dummy=0);
    void diagram();
};

class WVcrSelectorWindow : public UIWindow {
    WVcrSelector& sel;
    UIKeyTranslator translator;
 public:
    WVcrSelectorWindow(WVcrSelector& sel);
    ~WVcrSelectorWindow();

    bool handleCommand(const UICommand& cmd, UIBaseWidget& sender);
};

#endif
