/**
  *  \file client/widgets/configstorage.h
  *  \brief WConfigStorageControl widget
  */
#ifndef PCC_V2_CLIENT_WIDGETS_CONFIGSTORAGE_H
#define PCC_V2_CLIENT_WIDGETS_CONFIGSTORAGE_H

#include <vector>
#include "ui/widgets/button.h"
#include "util/conf.h"

/** Configuration option storage selection.
    This widget displays where configuration options are stored and allows the user to change it.
    It has an autosave mode where the change is effective immediately, and a regular mode where
    it requires a call to save().

    The options are configured using addOption(). The set can be changed by calling clear() and
    using addOption() again. */
class WConfigStorageControl : public UIWidget {
 public:
    WConfigStorageControl(bool autosave);
    ~WConfigStorageControl();

    void getLayoutInfo(LayoutInfo& info);
    void drawContent(GfxCanvas& can);
    void onResize(GfxRect oldSize, bool byLayout);

    void clear();
    void addOption(ConfigOption& opt);

    void save();

    Signal0 sig_change;

 private:
    UIButton btn_select;
    std::vector<ConfigOption*> options;
    bool autosave;
    int status;

    void onSelect();
};

#endif
