/**
  *  \file game/parser.h
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_PARSER_H
#define PCC_V2_GAME_PARSER_H

#include <vector>
#include <utility>
#include "cpluslib/string.h"
#include "cpluslib/types.h"
#include "cpluslib/object.h"
#include "cpluslib/ptrvector.h"

enum GMessageObject {
    MessageShip,
    MessagePlanet,
    MessageStarbase,
    MessageMinefield,
    MessageIonStorm,
    MessageExplosion,
    MessageConfig,
    MessagePlayerScore,
    MessageNoObject
};

typedef Object GMessageValueBase;

template<typename Index, typename Value>
class GMessageValue : public GMessageValueBase {
    Index index;
    Value value;
 public:
    GMessageValue(Index index, Value value);
    virtual ~GMessageValue();

    Index getIndex() const
        { return index; }

    Value getValue() const
        { return value; }

    void setValue(Value v)
        { this->value = v; }
};

enum GMessageStringIndex {
    ms_Name,
    ms_FCode,
    ms_Max
};

enum GMessageIntIndex {
    /* Generic: */
    mi_X,
    mi_Y,
    mi_Radius,
    mi_Owner,
    mi_Damage,
    mi_Heading,
    mi_Speed,

    /* Minefields: */
    mi_MineUnits,
    mi_MineScanReason,
    mi_MineType,
    mi_MineUnitsRemoved,

    /* Ships: */
    mi_ShipHull,
    mi_ShipFuel,

    /* Planets: */
    mi_PlanetTotalN,            // Total minerals, as in Dark Sense or Super Spy
    mi_PlanetTotalT,
    mi_PlanetTotalD,
    mi_PlanetTotalM,
    mi_PlanetAddedN,            // Added minerals, as in Meteor
    mi_PlanetAddedT,
    mi_PlanetAddedD,
    mi_PlanetAddedM,
    mi_PlanetMinedN,            // Mined minerals, as in Allied Planet
    mi_PlanetMinedT,
    mi_PlanetMinedD,
    mi_PlanetMinedM,
    mi_PlanetCash,
    mi_PlanetSupplies,
    mi_PlanetHasBase,
    mi_PlanetMines,
    mi_PlanetFactories,
    mi_PlanetDefense,
    mi_PlanetTemperature,
    mi_PlanetColonists,
    mi_PlanetActivity,
    mi_PlanetNativeRace,
    mi_PlanetNativeGov,
    mi_PlanetNatives,
    mi_PlanetHasNatives,

    /* Bases: */
    mi_BaseQueuePos,
    mi_BaseQueuePriority,

    /* Score: */
    mi_ScoreWinLimit,
    mi_ScoreTurnLimit,

    /* Storm: */
    mi_IonVoltage,
    mi_IonStatus,

    // TODO: TUtil7Battle
    // TODO: TUtil10Target
    // TODO: TUtil14Wormhole
    // TODO: TUtil17Ion
    // TODO: TUtil33GO
    // TODO: TUtil34FTP
    // TODO: TUtil38PAL
    // TODO: TUtil42GODestroyed
    // TODO: TUtil43MinefieldQuota
    // TODO: TUtil47NonExistantPlanets
    // TODO: Scores
    // TODO: TUtil57Special

    mi_Max
};

typedef GMessageValue<GMessageStringIndex,string_t> GMessageStringValue;
typedef GMessageValue<GMessageIntIndex,int32_t>     GMessageIntValue;
typedef GMessageValue<string_t,string_t>            GMessageConfigValue;
typedef GMessageValue<int,int32_t>                  GMessageScoreValue;

class GMessageInformation {
    typedef ptr_vector<GMessageValueBase> values_t;
    GMessageObject obj;
    int32          id;
    values_t       values;
    int            turn;

 public:
    typedef values_t::const_iterator iterator, const_iterator;

    GMessageInformation(GMessageObject obj, int32 id, int turn);
    ~GMessageInformation();

    void addValue(GMessageStringIndex si, const string_t& s);
    void addValue(GMessageIntIndex ii, int32 i);
    void addConfigValue(string_t key, string_t value);
    void addScoreValue(int player, int32_t value);

    iterator begin() const
        { return values.begin(); }
    iterator end() const
        { return values.end(); }

    GMessageObject getObjectType() const
        { return obj; }
    int32 getObjectId() const
        { return id; }
    int getTurnNumber() const
        { return turn; }
};


template<typename Index, typename Value>
GMessageValue<Index,Value>::GMessageValue(Index index, Value value)
    : index(index), value(value)
{ }

template<typename Index, typename Value>
GMessageValue<Index,Value>::~GMessageValue()
{ }

const char* getNameForItem(GMessageStringIndex si);
const char* getNameForItem(GMessageIntIndex ii);

GMessageStringIndex getStringIndexFromKeyword(string_t kw);
GMessageIntIndex getIntIndexFromKeyword(string_t kw);

#endif
