/**
  *  \file game/racename.h
  *  \brief Reading and Writing of Race Name files
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_RACENAME_H
#define PCC_V2_GAME_RACENAME_H

#include "cpluslib/string.h"

class Stream;

/** Race name list. Routines to parse, query, and modify a race.nm file.
    This also supports "players" 0 and 12, meaning unowned and alien objects.
    For each player, there are three names: the full name used in headings,
    the short name used in text ("The Lizards have captured our ship"), and
    the adjective ("We captured a Robotic ship"). */
class GRaceNameList {
    string_t short_names[13];
    string_t full_names[13];
    string_t adjectives[13];

 public:
    enum {
        ShortNameSize = 20,     /**< Maximum length of a short name. */
        FullNameSize  = 30,     /**< Maximum length of a full name. */
        AdjNameSize   = 12      /**< Maximum length of an adjective. */
    };

    GRaceNameList();
    GRaceNameList(Stream& s);
    ~GRaceNameList();

    void             load(Stream&);
    void             save(Stream&) const;

    const string_t&  getShortName(int player) const;
    const string_t&  getFullName(int player) const;
    const string_t&  getAdjName(int player) const;

    void             setShortName(int player, const string_t& s);
    void             setFullName(int player, const string_t& s);
    void             setAdjName(int player, const string_t& s);

    string_t         expandNames(string_t text) const;
};

extern GRaceNameList player_racenames;
extern GRaceNameList host_racenames;

extern const struct ModuleInitializer mod_racenames[];

#endif
