/**
  *  \file gfx/gfxnull.cc
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "gfx/gfx.h"

/** \class GfxNullCanvas
    \brief A graphics sink

    A null canvas ignores all requests. This can be used to 'silence'
    output. */

GfxNullCanvas::~GfxNullCanvas()
{ }

void
GfxNullCanvas::drawHLine(const GfxPoint& /*pt*/, int /*npix*/, uint32 /*color*/, uint8 /*pat*/, alpha_type /*alpha*/)
{ }

void
GfxNullCanvas::drawVLine(const GfxPoint& /*pt*/, int /*npix*/, uint32 /*color*/, uint8 /*pat*/, alpha_type /*alpha*/)
{ }

void
GfxNullCanvas::drawPixel(const GfxPoint& /*pt*/, uint32 /*color*/, alpha_type /*alpha*/)
{ }

void
GfxNullCanvas::drawBar(GfxRect /*rect*/, uint32 /*color*/, uint32 /*bg*/, const GfxFillPattern& /*pat*/, alpha_type /*alpha*/)
{ }

void
GfxNullCanvas::blitSurface(const GfxPoint& /*pt*/, GfxCanvas& /*src*/, GfxRect /*rect*/)
{ }

void
GfxNullCanvas::blitPattern(GfxRect /*rect*/, const GfxPoint& /*pt*/, int /*bytes_per_line*/, const uint8* /*data*/, uint32 /*color*/, uint32 /*bg*/, alpha_type /*alpha*/)
{ }

bool
GfxNullCanvas::lock()
{
    return true;
}

void
GfxNullCanvas::unlock()
{ }

void
GfxNullCanvas::update(GfxRect /*r*/)
{ }

GfxRect
GfxNullCanvas::computeClipRect(GfxRect r)
{
    // tell 'em we clip away everything.
    return GfxRect(r.x, r.y, 0, 0);
}

GfxPoint
GfxNullCanvas::getSize()
{
    return GfxPoint(1, 1);
}

int
GfxNullCanvas::getBitsPerPixel()
{
    return 1;
}

uint32
GfxNullCanvas::getPixel(const GfxPoint& /*pt*/)
{
    return 0;
}
