/**
  *  \file int/if/vcrif.h
  *  \brief Interpreter Game Interface: VCRs
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_IF_VCRIF_H
#define PCC_V2_INT_IF_VCRIF_H

#include "int/context.h"

class IntValue;
class IntArgBlock;
class GVcrEntry;
class GClassicVcrEntry;

IntValue*   IFVcrGet(IntArgBlock& args);
IntContext* IFVcrMake();

/** VCR context. */
class IntVcrContext : public IntContext {
    int vcrnr;
 public:
    IntVcrContext(int vcrnr);
    ~IntVcrContext();

    // IntContext:
    int32_t   lookup(const string_t& name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
    GObject*  getObject();
    string_t  toString(bool readable);
    void      store(IntTagNode& sv, Stream& aux);
    void      enumProperties(IntPropertyAcceptor& acceptor);
};

/** Property of one side of a VCR. */
enum IntVcrSideProperty {
    ivsAuxAmmo,
    ivsAuxCount,
    ivsAuxId,
    ivsAuxName,
    ivsAuxShort,
    ivsFighterBays,
    ivsFighterCount,
    ivsTorpId,
    ivsTorpCount,
    ivsTorpLCount,
    ivsTorpShort,
    ivsTorpName,
    ivsBeamCount,
    ivsBeamId,
    ivsBeamName,
    ivsBeamShort,
    ivsCrew,
    ivsCrewRaw,
    ivsDamage,
    ivsId,
    ivsMass,
    ivsName,
    ivsNameFull,
    ivsOwnerAdj,
    ivsOwnerId,
    ivsOwnerShort,
    ivsShield,
    ivsStatus,
    ivsStatusRaw,
    ivsType,
    ivsTypeShort,
    ivsHullName,
    ivsHullId,
    ivsImage,
    ivsLevel,
    ivsIsPlanet
};

/** Property of a VCR record. */
enum IntVcrProperty {
    ivpSeed,
    ivpMagic,
    ivpType,
    ivpAlgorithm,
    ivpFlags,
    ivpNumUnits,
    ivpUnits
};

IntValue* getVcrSideProperty(GVcrEntry& vcr, int side, IntVcrSideProperty ivs);
IntValue* getVcrProperty(GVcrEntry& vcr, IntVcrProperty ivp);

#endif
