/**
  *  \file int/keywords.cc
  *  \brief Interpreter: Keywords
  *
  *  Contains a list of all keywords, i.e. all fundamental commands.
  *
  *  (c) 2001-2012 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "int/keywords.h"
#include "cpluslib/misc.h"

static const char*const keyword_table[] = {
    "ABORT",
    "BIND",
    "BREAK",
    "CASE",
    "CONTINUE",
    "CREATEKEYMAP",
    "CREATEPLANETPROPERTY",
    "CREATESHIPPROPERTY",
    "DIM",
    "DO",
    "ELSE",
    "END",
    "ENDFUNCTION",
    "ENDIF",
    "ENDSELECT",
    "ENDSTRUCT",
    "ENDSUB",
    "ENDTRY",
    "ENDWITH",
    "EVAL",
    "FOR",
    "FOREACH",
    "FUNCTION",
    "IF",
    "LOAD",
    "LOCAL",
    "LOOP",
    "NEXT",
    "ON",
    "OPTION",
    "PRINT",
    "RESTART",
    "RETURN",
    "RUNHOOK",
    "SELECT",
    "SELECTIONEXEC",
    "SHARED",
    "STATIC",
    "STOP",
    "STRUCT",
    "SUB",
    "TRY",
    "TRYLOAD",
    "UNTIL",
    "WHILE",
    "WITH",
};

/** Check whether the given string is a keyword. */
IntKeyword
lookupKeyword(const string_t& s)
{
    // FIXME: use binary search....
    for (unsigned i = 0; i < countof(keyword_table); ++i)
        if (keyword_table[i] == s)
            return IntKeyword(i+1);
    return kwNone;
}
